@@ -189,7 +189,7 @@ fn get_rustc_link_lib(_: &PythonVersion, ld_version: &str, enable_shared: bool)
 
 #[cfg(target_os="macos")]
 fn get_macos_linkmodel() -> Result<String, String> {
-    let script = "import MacOS; print MacOS.linkmodel;";
+    let script = "import sysconfig; print('framework' if sysconfig.get_config_var('PYTHONFRAMEWORK') else ('shared' if sysconfig.get_config_var('Py_ENABLE_SHARED') else 'static'));";
     let out = run_python_script("python", script).unwrap();
     Ok(out.trim_right().to_owned())
 }
@@ -225,7 +225,7 @@ fn get_interpreter_version(line: &str) -> Result<PythonVersion, String> {
 #[cfg(target_os="windows")]
 fn get_rustc_link_lib(version: &PythonVersion, _: &str, _: bool) -> Result<String, String> {
     // Py_ENABLE_SHARED doesn't seem to be present on windows.
-    Ok(format!("cargo:rustc-link-lib=python{}{}", version.major, 
+    Ok(format!("cargo:rustc-link-lib=pythonXY:python{}{}", version.major, 
         match version.minor {
             Some(minor) => minor.to_string(),
             None => "".to_owned()
@@ -298,8 +298,16 @@ fn configure_from_path(expected_version: &PythonVersion) -> Result<String, Strin
     let ld_version: &str = &lines[3];
     let exec_prefix: &str = &lines[4];
 
-    println!("{}", get_rustc_link_lib(&interpreter_version,
-        ld_version, enable_shared == "1").unwrap());
+    let is_extension_module = env::var_os("CARGO_FEATURE_EXTENSION_MODULE").is_some();
+    if !is_extension_module || cfg!(target_os="windows") {
+        println!("{}", get_rustc_link_lib(&interpreter_version,
+            ld_version, enable_shared == "1").unwrap());
+        if libpath != "None" {
+            println!("cargo:rustc-link-search=native={}", libpath);
+        } else if cfg!(target_os="windows") {
+            println!("cargo:rustc-link-search=native={}\\libs", exec_prefix);
+        }
+    }
 
     let is_pep_384 = env::var_os("CARGO_FEATURE_PEP_384").is_some();
     if is_pep_384 {
@@ -312,12 +320,6 @@ fn configure_from_path(expected_version: &PythonVersion) -> Result<String, Strin
         }
     }
 
-    if libpath != "None" {
-        println!("cargo:rustc-link-search=native={}", libpath);
-    } else if cfg!(target_os="windows") {
-        println!("cargo:rustc-link-search=native={}\\libs", exec_prefix);
-    }
-
     return Ok(interpreter_path);
 }
 
