@@ -1,7 +1,7 @@
 use libc::c_int;
 use object::PyObject;
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn PyEval_EvalCode(arg1: *mut PyObject, arg2: *mut PyObject,
                            arg3: *mut PyObject) -> *mut PyObject;
     pub fn PyEval_EvalCodeEx(co: *mut PyObject, globals: *mut PyObject,
