@@ -1,6 +1,6 @@
 use libc::c_int;
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn PyOS_InterruptOccurred() -> c_int;
     pub fn PyOS_InitInterrupts() -> ();
     pub fn PyOS_AfterFork() -> ();
