@@ -287,6 +287,62 @@ mod typeobject {
     impl Default for PyNumberMethods {
         #[inline] fn default() -> Self { unsafe { ::core::mem::zeroed() } }
     }
+    macro_rules! as_expr { ($e:expr) => {$e} }
+
+
+    macro_rules! py_number_methods_init {
+        ($($tail:tt)*) => {
+            as_expr! {
+                PyNumberMethods {
+                    nb_add: None,
+                    nb_subtract: None,
+                    nb_multiply: None,
+                    nb_remainder: None,
+                    nb_divmod: None,
+                    nb_power: None,
+                    nb_negative: None,
+                    nb_positive: None,
+                    nb_absolute: None,
+                    nb_bool: None,
+                    nb_invert: None,
+                    nb_lshift: None,
+                    nb_rshift: None,
+                    nb_and: None,
+                    nb_xor: None,
+                    nb_or: None,
+                    nb_int: None,
+                    nb_reserved: 0 as *mut c_void,
+                    nb_float: None,
+                    nb_inplace_add: None,
+                    nb_inplace_subtract: None,
+                    nb_inplace_multiply: None,
+                    nb_inplace_remainder: None,
+                    nb_inplace_power: None,
+                    nb_inplace_lshift: None,
+                    nb_inplace_rshift: None,
+                    nb_inplace_and: None,
+                    nb_inplace_xor: None,
+                    nb_inplace_or: None,
+                    nb_floor_divide: None,
+                    nb_true_divide: None,
+                    nb_inplace_floor_divide: None,
+                    nb_inplace_true_divide: None,
+                    nb_index: None,
+                    $($tail)*
+                }
+            }
+        }
+    }
+
+    #[cfg(not(Py_3_5))]
+    pub const PyNumberMethods_INIT: PyNumberMethods = py_number_methods_init!();
+
+    #[cfg(Py_3_5)]
+    pub const PyNumberMethods_INIT: PyNumberMethods = py_number_methods_init! {
+        nb_matrix_multiply: None,
+        nb_inplace_matrix_multiply: None,
+    };
+
     #[repr(C)]
     #[derive(Copy)]
     pub struct PySequenceMethods {
@@ -307,6 +363,18 @@ mod typeobject {
     impl Default for PySequenceMethods {
         #[inline] fn default() -> Self { unsafe { ::core::mem::zeroed() } }
     }
+    pub const PySequenceMethods_INIT : PySequenceMethods = PySequenceMethods {
+        sq_length: None,
+        sq_concat: None,
+        sq_repeat: None,
+        sq_item: None,
+        was_sq_slice: 0 as *mut _,
+        sq_ass_item: None,
+        was_sq_ass_slice: 0 as *mut _,
+        sq_contains: None,
+        sq_inplace_concat: None,
+        sq_inplace_repeat: None,
+    };
     #[repr(C)]
     #[derive(Copy)]
     pub struct PyMappingMethods {
@@ -320,6 +388,11 @@ mod typeobject {
     impl Default for PyMappingMethods {
         #[inline] fn default() -> Self { unsafe { ::core::mem::zeroed() } }
     }
+    pub const PyMappingMethods_INIT : PyMappingMethods = PyMappingMethods {
+        mp_length: None,
+        mp_subscript: None,
+        mp_ass_subscript: None,
+    };
     #[repr(C)]
     #[derive(Copy)]
     #[cfg(Py_3_5)]
@@ -336,6 +409,12 @@ mod typeobject {
     impl Default for PyAsyncMethods {
         #[inline] fn default() -> Self { unsafe { ::core::mem::zeroed() } }
     }
+    #[cfg(Py_3_5)]
+    pub const PyAsyncMethods_INIT : PyAsyncMethods = PyAsyncMethods {
+        am_await: None,
+        am_aiter: None,
+        am_anext: None,
+    };
     #[repr(C)]
     #[derive(Copy)]
     pub struct PyBufferProcs {
@@ -418,10 +497,105 @@ mod typeobject {
     impl Clone for PyTypeObject {
         #[inline] fn clone(&self) -> Self { *self }
     }
-    impl Default for PyTypeObject {
-        #[inline] fn default() -> Self { unsafe { ::core::mem::zeroed() } }
+
+    macro_rules! py_type_object_init {
+        ($tp_as_async:ident, $($tail:tt)*) => {
+            as_expr! {
+                PyTypeObject {
+                    ob_base: ::object::PyVarObject {
+                        ob_base: ::object::PyObject_HEAD_INIT,
+                        ob_size: 0
+                    },
+                    tp_name: 0 as *const c_char,
+                    tp_basicsize: 0,
+                    tp_itemsize: 0,
+                    tp_dealloc: None,
+                    tp_print: None,
+                    tp_getattr: None,
+                    tp_setattr: None,
+                    $tp_as_async: 0 as *mut _,
+                    tp_repr: None,
+                    tp_as_number: 0 as *mut PyNumberMethods,
+                    tp_as_sequence: 0 as *mut PySequenceMethods,
+                    tp_as_mapping: 0 as *mut PyMappingMethods,
+                    tp_hash: None,
+                    tp_call: None,
+                    tp_str: None,
+                    tp_getattro: None,
+                    tp_setattro: None,
+                    tp_as_buffer: 0 as *mut PyBufferProcs,
+                    tp_flags: ::object::Py_TPFLAGS_DEFAULT,
+                    tp_doc: 0 as *const c_char,
+                    tp_traverse: None,
+                    tp_clear: None,
+                    tp_richcompare: None,
+                    tp_weaklistoffset: 0,
+                    tp_iter: None,
+                    tp_iternext: None,
+                    tp_methods: 0 as *mut ::methodobject::PyMethodDef,
+                    tp_members: 0 as *mut ::structmember::PyMemberDef,
+                    tp_getset: 0 as *mut ::descrobject::PyGetSetDef,
+                    tp_base: 0 as *mut PyTypeObject,
+                    tp_dict: 0 as *mut ::object::PyObject,
+                    tp_descr_get: None,
+                    tp_descr_set: None,
+                    tp_dictoffset: 0,
+                    tp_init: None,
+                    tp_alloc: None,
+                    tp_new: None,
+                    tp_free: None,
+                    tp_is_gc: None,
+                    tp_bases: 0 as *mut ::object::PyObject,
+                    tp_mro: 0 as *mut ::object::PyObject,
+                    tp_cache: 0 as *mut ::object::PyObject,
+                    tp_subclasses: 0 as *mut ::object::PyObject,
+                    tp_weaklist: 0 as *mut ::object::PyObject,
+                    tp_del: None,
+                    tp_version_tag: 0,
+                    $($tail)*
+                }
+            }
+        }
     }
 
+    #[cfg(py_sys_config="COUNT_ALLOCS")]
+    macro_rules! py_type_object_init_with_count_allocs {
+        ($tp_as_async:ident, $($tail:tt)*) => {
+            py_type_object_init!($tp_as_async,
+                $($tail)*
+                tp_allocs: 0,
+                tp_frees: 0,
+                tp_maxalloc: 0,
+                tp_prev: 0 as *mut PyTypeObject,
+                tp_next: 0 as *mut PyTypeObject,
+            )
+        }
+    }
+
+    #[cfg(not(py_sys_config="COUNT_ALLOCS"))]
+    macro_rules! py_type_object_init_with_count_allocs {
+        ($tp_as_async:ident, $($tail:tt)*) => {
+            py_type_object_init!($tp_as_async, $($tail)*)
+        }
+    }
+
+    #[cfg(Py_3_5)]
+    pub const PyTypeObject_INIT: PyTypeObject = py_type_object_init_with_count_allocs!(
+        tp_as_async,
+        tp_finalize: None,
+    );
+
+    #[cfg(all(Py_3_4, not(Py_3_5)))]
+    pub const PyTypeObject_INIT: PyTypeObject = py_type_object_init_with_count_allocs!(
+        tp_reserved,
+        tp_finalize: None,
+    );
+
+    #[cfg(not(Py_3_4))]
+    pub const PyTypeObject_INIT: PyTypeObject = py_type_object_init_with_count_allocs!(
+        tp_reserved,
+    );
+
     #[repr(C)]
     #[derive(Copy)]
     pub struct PyHeapTypeObject {
@@ -483,7 +657,7 @@ impl Default for PyType_Spec {
     fn default() -> PyType_Spec { unsafe { ::core::mem::zeroed() } }
 }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn PyType_FromSpec(arg1: *mut PyType_Spec) -> *mut PyObject;
 
     //#[cfg(Py_3_3)]
@@ -495,7 +669,7 @@ extern "C" {
         -> *mut c_void;
 }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn PyType_IsSubtype(a: *mut PyTypeObject, b: *mut PyTypeObject) -> c_int;
 }
 
@@ -504,7 +678,7 @@ pub unsafe fn PyObject_TypeCheck(ob: *mut PyObject, tp: *mut PyTypeObject) -> c_
     (Py_TYPE(ob) == tp || PyType_IsSubtype(Py_TYPE(ob), tp) != 0) as c_int
 }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     /// built-in 'type'
     pub static mut PyType_Type: PyTypeObject;
     /// built-in 'object'
@@ -525,7 +699,7 @@ pub unsafe fn PyType_CheckExact(op: *mut PyObject) -> c_int {
     (Py_TYPE(op) == &mut PyType_Type) as c_int
 }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn PyType_Ready(t: *mut PyTypeObject) -> c_int;
     pub fn PyType_GenericAlloc(t: *mut PyTypeObject, nitems: Py_ssize_t)
      -> *mut PyObject;
@@ -559,16 +733,6 @@ extern "C" {
                             arg3: *mut PyObject) -> c_int;
     pub fn PyObject_HasAttr(arg1: *mut PyObject, arg2: *mut PyObject)
      -> c_int;
-    /*pub fn _PyObject_IsAbstract(arg1: *mut PyObject) -> c_int;
-    pub fn _PyObject_GetAttrId(arg1: *mut PyObject,
-                               arg2: *mut Struct__Py_Identifier)
-     -> *mut PyObject;
-    pub fn _PyObject_SetAttrId(arg1: *mut PyObject,
-                               arg2: *mut Struct__Py_Identifier,
-                               arg3: *mut PyObject) -> c_int;
-    pub fn _PyObject_HasAttrId(arg1: *mut PyObject,
-                               arg2: *mut Struct__Py_Identifier)
-     -> c_int;*/
     pub fn PyObject_SelfIter(arg1: *mut PyObject) -> *mut PyObject;
 
     #[cfg(not(Py_LIMITED_API))]
@@ -660,7 +824,7 @@ pub unsafe fn PyType_FastSubclass(t : *mut PyTypeObject, f : c_ulong) -> c_int {
     PyType_HasFeature(t, f)
 }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn _Py_Dealloc(arg1: *mut PyObject) -> ();
 }
 
@@ -709,7 +873,7 @@ pub unsafe fn Py_XDECREF(op : *mut PyObject) {
     }
 }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn Py_IncRef(o: *mut PyObject);
     pub fn Py_DecRef(o: *mut PyObject);
 
