@@ -2,7 +2,7 @@ use libc::{c_char, c_int};
 use pyport::Py_ssize_t;
 use object::*;
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn PyErr_SetNone(arg1: *mut PyObject) -> ();
     pub fn PyErr_SetObject(arg1: *mut PyObject, arg2: *mut PyObject) -> ();
     pub fn PyErr_SetString(exception: *mut PyObject,
@@ -52,7 +52,7 @@ pub unsafe fn PyExceptionInstance_Class(x: *mut PyObject) -> *mut PyObject {
     (*x).ob_type as *mut PyObject
 }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub static mut PyExc_BaseException: *mut PyObject;
     pub static mut PyExc_Exception: *mut PyObject;
     pub static mut PyExc_StopIteration: *mut PyObject;
@@ -66,6 +66,8 @@ extern "C" {
     pub static mut PyExc_FloatingPointError: *mut PyObject;
     pub static mut PyExc_OSError: *mut PyObject;
     pub static mut PyExc_ImportError: *mut PyObject;
+    #[cfg(Py_3_6)]
+    pub static mut PyExc_ModuleNotFoundError: *mut PyObject;
     pub static mut PyExc_IndexError: *mut PyObject;
     pub static mut PyExc_KeyError: *mut PyObject;
     pub static mut PyExc_KeyboardInterrupt: *mut PyObject;
@@ -135,6 +137,10 @@ extern "C" {
      -> *mut PyObject;
     pub fn PyErr_Format(exception: *mut PyObject,
                         format: *const c_char, ...) -> *mut PyObject;
+    #[cfg(Py_3_6)]
+    pub fn PyErr_SetImportErrorSubclass(
+        arg1: *mut PyObject, arg2: *mut PyObject,
+        arg3: *mut PyObject, arg4: *mut PyObject) -> *mut PyObject;
     pub fn PyErr_SetImportError(arg1: *mut PyObject, arg2: *mut PyObject,
                                 arg3: *mut PyObject) -> *mut PyObject;
     pub fn PyErr_BadInternalCall() -> ();
